# Strip Groups
group andrews
	desc Andrew's Favorite Strips
	include userfriendly dilbert foxtrot
	include pennyarcade joyoftech thefifthwave monty bc
	include wizardofid garfield adamathome
end

group michael
	desc Michael's Favorite Strips
	include foxtrot boondocks doonesbury zits dilbert babyblues
	include monty bc blondie calvinandhobbes funkywinkerbean
	include zippythecolorpinhead peanuts adamathome forbetter bizarro
	include userfriendly geech shoe wizardofid
end

group gloucestertimes
	desc Gloucester Daily Times Strips
	include garfield broomhilda bc wizardofid roseisrose
	include dilbert cathy sallyforth monty grimmy peanuts
	include forbetter foxtrot offthemark
end

group bgsunday
	desc Boston Globe Sunday Comics
	include dilbert doonesbury garfield getfuzzy adamathome grimmy forbetter
	include foxtrot jumpstart zits zippythecolorpinhead curtis
	include rhymeswithorange boondocks nonsequitur stonesoup roseisrose monty
	include arlonjanis askshagg
end

# Class definitions
class ucomics-srch
	homepage http://www.ucomics.com/$strip/view$1.htm
	type search
	searchpattern <img.+?src=".+?(/$1/(\d+)/$1(\d+).+?)"
	baseurl http://images.ucomics.com/comics
	provides latest
end

class ucomics-gen
	homepage http://www.ucomics.com/$strip/view$1.htm
	type generate
	imageurl http://images.ucomics.com/comics/$1/%Y/$1%y%m%d.gif
	provides any

end

class unitedmedia-srch-comics
	homepage http://www.unitedmedia.com/comics/$strip/index.html
	type search
	searchpage http://www.unitedmedia.com/comics/$strip/archive/$strip-%Y%m%d.html
	searchpattern <img.+?src="(/comics/$strip/archive/images/$strip.+?)"
	baseurl http://www.unitedmedia.com
	provides any
end

class unitedmedia-srch-comics-lag
	homepage http://www.unitedmedia.com/comics/$strip/index.html
	type search
	searchpattern <img.+?src="(/comics/$strip/archive/images/$strip.+?)"
	baseurl http://www.unitedmedia.com
	provides latest
end

class unitedmedia-srch-creators
	homepage http://www.unitedmedia.com/creators/$strip/index.html
	type search
	searchpattern <img.+?src="?(/creators/$strip/archive/images/.+?\.(gif|jpg))"?
	baseurl http://www.unitedmedia.com
	provides latest
end

class unitedmedia-srch-wash
	homepage http://www.unitedmedia.com/wash/$strip/index.html
	type search
	searchpattern (/wash/$strip/archive/images/(.*?)\.(gif|jpg))
	baseurl http://www.unitedmedia.com
	provides latest
end

class unitedmedia-srch-editoons
	homepage http://www.unitedmedia.com/editoons/$1/index.html
	type search
	searchpattern <img src="(/editoons/$1/archive/images/$1\d+\..+?)"
	baseurl http://www.unitedmedia.com
	provides latest
end

class sfgate-gen-zippycolor
	homepage http://www.sfgate.com/cgi-bin/article.cgi?file=/comics/$1.dtl
	type generate
	imageurl http://pst.rbma.com/content/$2
	provides latest
end

class sfgate-gen
	homepage http://www.sfgate.com/cgi-bin/article.cgi?file=/comics/$1.dtl
	type generate
	imageurl http://pst.rbma.com/content/$1
	provides latest
	prefetch $homepage
end

class sfgate-srch
	homepage http://www.sfgate.com/cgi-bin/article.cgi?file=/comics/$1.dtl
	type search
	searchpattern <img.+?src=".+?(/comics/graphics/$2/.+?\..+?)"
	baseurl http://www.sfgate.com
	provides latest
end

#use POSIX;my $d=strftime("\%"."w",localtime($time_today));$l = "s" if$w==0;$l = "a" if$w!=0;"foo$l"

#use POSIX;
#if (strftime("\%"."w",localtime($time_today)) == 0)
#{$l = "s"}
#else
#{$l = "a"}
#"$a"

class comicspage-strips-gen
        # $1 - more or less the real name
        # $2 - 3-letter abbreviation of $1
        referer http://www.comicspage.com/$1/index.html
        homepage http://www.comicspage.com/$1/index.html
        type generate
        imageurl http://www.tmsfeatures.com/tmsfeatures/servlet/com.featureserv.util.Download?file=%Y%m%dcs$2-<code:"s" if %w==0><code:"a" if %w!=0>-p.jpg&code=cs$2
        provides any
end

class comicspage-panels-gen
	# $1 - more or less the real name
	# $2 - 3-letter abbreviation of $1
	homepage http://www.comicspage.com/$1/index.html
	#type search
	#searchpage http://www.comicspage.com/$1/main.html
	#searchpattern <img.+?src="(http://www.comicspage.com/daily/cp$2/\d+cp$2((-\w)?)\..+?)"
	type generate
	imageurl http://www.tmsfeatures.com/tmsfeatures/servlet/com.featureserv.util.Download?file=%Y%m%dcp$2-<code:"s" if %w==0><code:"a" if %w!=0>-p.jpg&code=cp$2
	#provides latest
	provides any
end

class comicspage-editorial-gen
	# $1 - more or less the real name
	# $2 - 3-letter abbreviation of $1
	homepage http://www.comicspage.com/$1/index.html
	#type search
	#searchpage http://www.comicspage.com/$1/main.html
	#searchpattern <img.+?src="(http://www.comicspage.com/daily/ed$2/\d+ed$2((-\w)?)\..+?)"
	#provides latest
	type generate
	imageurl http://www.tmsfeatures.com/tmsfeatures/servlet/com.featureserv.util.Download?file=%Y%m%ded$2-a-p.jpg&code=ed$2
	provides any
end

class mercurycenter
        # $1 - number of strip (unique to Mercury Center?)
        # $2 - name of strip spaces=_?
        homepage http://cgi.mercurycenter.com/cgi-bin/comics/show.cgi?ID=$1&DATE=TODAY
        type generate
        imageurl http://cgi.mercurycenter.com/premium/comics/%m_%d/$2.gif
        provides any
end

class sev-comics
        homepage http://www.sev.com.au/toonzone/$strip.asp
        type generate
        imageurl http://www.sev.com.au/toonzone/$strip.jpg
        provides latest
end

class washpost-creators
        homepage http://featurepage.creators.com/washpost.html?name=$1
        type generate
	prefetch $homepage
        imageurl http://www.creators.com/<code:use POSIX;my$o=0;while(strftime("\%"."w",localtime($time_today-86400*$o))!=0){$o++}my$d=strftime("\%"."m"."\%"."d",localtime($time_today-86400*$o));"$d">/$1/$1%m%dg.gif
        provides any
end



class washpost-king
        homepage http://www.washingtonpost.com/wp-srv/style/comics/king.htm?$1
        prefetch $homepage
        imageurl http://est.rbma.com/content/$1
        type generate
        provides latest
end


# Non-standard strips

# should be possible to generate?
# sometimes multi-image - need a new way to handle this
strip avalonhigh
	name Avalon High
	homepage http://www.avalonhigh.com/
	type search
	searchpattern <IMG.+?SRC="(/?comics/avalon\d{8}.*?\.gif)"
	baseurl $homepage
	provides latest
end

strip drfun
	name Doctor Fun
	homepage http://www.ibiblio.org/Dave/Dr-Fun/html/
	type generate
	imageurl http://www.ibiblio.org/Dave/Dr-Fun/html/Dr-Fun/latest.jpg
	provides latest
end

strip goats
	name Goats
	homepage http://www.goats.com/
	type search
	searchpattern <IMG.+?SRC="(/comix/\d+/goats\d+.gif)"
	baseurl http://www.goats.com/
	provides latest
end

strip jokesonyou
	name The Joke's on You
	homepage http://www.thefunnypages.com/
	type search
	searchpattern <img.+src="(http://www.thefunnypages.com/archives/.+?\.gif)"
	#updated daily or not? - check - seems to be, but check weekend
	provides latest
end

strip innies
	name Innies and Outies
	homepage http://www.inniesandoutties.com/
	type generate
	#updated M/W/F - no sense searching
	imageurl http://www.inniesandoutties.com/images/front.jpg
	provides latest
end

strip joyoftech
	name The Joy of Tech
	homepage http://www.joyoftech.com/joyoftech/
	type search
	searchpattern <IMG.+?src="(joyimages/\d+\.(gif|jpg))\"
	baseurl http://www.joyoftech.com/joyoftech/
	provides latest
end

strip megatokyo
	name MegaTokyo
	homepage http://www.megatokyo.com/
	type search
	searchpattern <IMG.+?SRC="(/?strips/\d+\.gif)"
	baseurl http://www.megatokyo.com/
	provides latest

end

strip mostlybusiness
	name Mostly Business
	homepage http://www.tedgoff.com/
	type generate
	#fix to use more precise addr - maybe not possible?
	imageurl http://www.tedgoff.com/mb/images/today.gif
	provides latest
end

# website gone (?) 2002-05-24
#strip notquiteright
#	name Not Quite Right
#	homepage http://www.notquiteright.com/
#	type generate
#	imageurl http://www.notquiteright.com/wow/todaystoon.gif
#	provides latest
#end

strip pennyarcade
	name Penny Arcade
	homepage http://www.penny-arcade.com/
	type search
	searchpage http://www.penny-arcade.com/view.php3
	searchpattern <img.+?src="(images/\d{4}/\d{8}l\..{3})"></td>
	#searchpattern <IMG.+?src="(images/200.+?\.gif)"></TD>
	baseurl http://www.penny-arcade.com/
	provides latest
end

strip plif
      name Parking Lot is Full
      homepage http://www.plif.com
      type generate
      imageurl http://www.plif.com/thisweek.gif
      provides latest
end

# gone? 2002-04-02
#strip punc
#	name Punc & Mark
#	homepage http://byteus.com/pm/
#	type search
#	searchpage http://artiztik.com/cgi-bin/pmviewer.cgi?list=pm&config=pm.cfg&slide=999&style=pm
#	searchpattern <img.+?src=(/pm/strips/.+?\.jpg)
#	baseurl http://artiztik.com/
#	provides latest
#end

strip pvp
	name Player vs. Player
	homepage http://www.pvponline.com/
	type generate
	imageurl http://www.pvponline.com/archive/%Y/pvp%Y%m%d.gif
	provides any
end

strip redmeat
	name Redmeat
	homepage http://www.redmeat.com/redmeat/current/
	type generate
	imageurl http://www.redmeat.com/redmeat/current/index-1.gif
	provides latest
end


strip rudypark
	name Rudy Park
	homepage http://www.rudypark.com/
	type generate
	imageurl http://www.rudypark.com/comics/rudy%Y%m%d.gif
	provides latest
end

strip sinfest
	name Sinfest
	homepage http://sinfest.net
	type generate
	imageurl http://sinfest.net/comics/sf%Y%m%d.gif
	provides any
end

strip sluggy
	name Sluggy Freelance
	homepage http://www.sluggy.com/
	type search
	searchpage http://www.sluggy.com/daily.php?date=%y%m%d
	searchpattern <img.+?src="?(http://pics.sluggy.com/comics/%y%m%d.+?\.(gif|jpg))
	provides any
end

# only updated M-F, but no better way to handle it
strip squinkers
	name Squinkers
	homepage http://www.squinkers.com/
	type generate
	imageurl http://www.squinkers.com/sqkrs/Images/today.gif
	provides latest
end

strip superosity
	name Superosity
	homepage http://www.superosity.com/
	type generate
	imageurl http://www.superosity.com/comics/sup%Y%m%d.gif
	provides any
end

#every day except sunday
strip theweedpatch
	name The WeedPatch
	homepage http://www.jpjennings.com/toons/
	type generate
	imageurl http://www.jpjennings.com/toons/%m%d%Y.gif
	provides any
end

strip userfriendly
	name User Friendly
	homepage http://www.userfriendly.org/static/
	type search
	searchpage http://ars.userfriendly.org/cartoons/?id=%Y%m%d&mode=classic
	searchpattern <img.+?src="(http://www.userfriendly.org/cartoons/archives/%y.+?/uf.+?\.gif)"
	provides any
end

strip exploitnow
	name Exploitation Now
	homepage http://www.exploitationnow.com/
	type search
	searchpattern <IMG.+?SRC="(/comics/rb\d+\..+?)"
	baseurl $homepage
	provides latest
end

strip coolcat
	name Cool Cat Studio
	homepage http://www.coolcatstudio.com/
	type search
	searchpattern <IMG.+?SRC="(/comics/ccs\d+\..+?)"
	baseurl http://www.coolcatstudio.com/
	provides latest
end

strip classm
	name The Class Menagerie
	homepage http://www.theclassm.com/
	type search
	searchpattern <IMG.+?SRC="(/comics/tcm\d+\..+?)"
	baseurl http://www.theclassm.com/
	provides latest
end

strip bruno
	name The Bruno Daily Times
	homepage http://www.brunostrip.com/bruno.html
	type generate
	imageurl http://www.brunostrip.com/%Ypics/%Y%m%d.gif
	provides any
end

strip nukees
	name Nukees
	homepage http://www.nukees.com
	type search
	searchpattern <IMG.+?SRC="(/comics/\d+\..+?)"
	baseurl http://www.nukees.com/
	provides latest
end

strip joeaverage
	name Joe Average
	homepage http://www.joeaverage.org
	type search
	searchpattern <IMG.+?SRC="(/comics/\d+\..+?)"
	baseurl http://www.joeaverage.org/
	provides latest
end

# seems to be gone: 10/26/01
#strip hotzp
#	name Bad Boys of Computer Science
#	homepage http://hotzp.com/badboys/
#	type generate
#	imageurl http://hotzp.com/badboys/new.jpg
#	provides latest
#end

strip angst
	name Angst Technology
	homepage http://www.inktank.com/AT/
	type generate
	imageurl http://www.inktank.com/images/AT/cartoons/%m-%d-%y.gif
	provides any
end

strip zapiro
	name Zapiro
	homepage http://www.mg.co.za/mg/zapiro/
	type generate
	imageurl http://www.chico.mweb.co.za/images/zapiro/%y-<code:lc(strftime("\%b", @localtime_today))>%d.gif
	provides any
end

strip clanofthecats
	name Clan of the cats
	homepage http://www.clanofthecats.com/
	type generate
	imageurl http://www.clanofthecats.com/comics/%Y%m%da.gif
	provides any
end

strip gpf
	name General Protection Fault
	homepage http://www.gpf-comics.com/
	type search
	searchpattern <IMG.+?SRC="(/comics/gpf\d+\..+?)"
	baseurl http://www.gpf-comics.com
	provides latest
end

#note: doesn't work perfectly - some strips are broken up into multiple images
# this is not yet supported, but could be done
strip crfh
	name College Roomies from Hell
	homepage http://www.crfh.net
	type generate
	imageurl http://www.crfh.net/comics/crfh%Y%m%d.jpg
	provides any
end

#generatable?
strip striptease
	name Strip Tease Comic
	homepage http://www.stripteasecomic.com/
	type search
	searchpattern <img.+?src="(/?strips\d+/\d+\..+?)"
	baseurl $homepage
	provides latest
end

strip dorktower
	name Dork Tower
	homepage http://www.dorktower.com/
	type search
	#searchpattern <IMG.+src="(comics/gamespy/GameSpy\d+\.jpg)".*?>
	#searchpattern <IMG.+?src="(comics/interactiveweek/IW\d+\(\d+_\d+_\d+\)\.jpg)"
	#searchpattern <img.+?src="(comics/dorktower/Dorktower\d+..+?)"
	#searchpattern <img.+?src="(comics/backups/.+?)"
	#searchpattern <img.+?src="(/(comics/(backups|gamespy|interactiveweek|dorktower)/.+?)"
	searchpattern <img.+?src="(/?images/comics/.+?\..+?)"
	baseurl $homepage
	provides latest
end

strip jerkcity
	name Jerkcity
	homepage http://www.jerkcity.com/
  	type generate
	imageurl http://www.jerkcity.com/today.gif
	provides latest
end

strip kevinandkell
	name Kevin and Kell
	homepage http://www.kevinandkell.com/
	type generate
	imageurl http://www.kevinandkell.com/%Y/strips/kk%Y%m%d.gif
	provides any
end

strip freefall
	name Freefall
	homepage http://www.purrsia.com/freefall/
	type generate
	imageurl $homepage<code:use POSIX;my $w=strftime("\%"."u",localtime($time_today));my $s=517+3*floor(($time_today-995839200)/604800);$s++if$w\>2;$s++if$w\>4;my$c=int(($s+99)/100);"ff${c}00/fv00$s.gif">
	provides any
end

strip 8bit
	name 8-Bit Theater
	homepage http://www.nuklearpower.com/comic/
	type search
	searchpattern <a.+?href="(\d+)\.htm">Newest Comic</a>
	imageurl http://www.nuklearpower.com/comic/ep$match.gif
	provides latest
end

strip apodbig
	name Astronomy Picture of the Day (big image)
	homepage http://antwrp.gsfc.nasa.gov/apod/
	type search
	searchpattern <a.+?href="(image/\d{4}/.+?\.(jpg|gif))"
	baseurl $homepage
	provides latest
end

strip apod
	name Astronomy Picture of the Day
	homepage http://antwrp.gsfc.nasa.gov/apod/
	type search
	searchpattern <img.+?SRC="(image/\d{4}/.+?\..+?)"
	baseurl $homepage
	provides latest
end


strip pgs
	name Pathetic Geek Stories
	homepage http://www.theonionavclub.com/
	type search
	searchpattern <a.+?HREF="/avclub\d+/pgs(\d+).html"
	#<FRAME.+?SRC="http://www.theonionavclub.com/avclub(\d+)/"
	imageurl http://graphics.theonion.com/avpics_$match/pgs_$match.gif
	provides latest
end

# seems to be '....a.gif' now.
strip adventurers
	name Adventurers!
	homepage http://www.adventurers-comic.com/
	type generate
	imageurl http://www.adventurers-comic.com/comics/adventurers%Y%m%da.gif
	provides any
end

# discontinued 2002-05-24
# may be updated to download old strips
#strip basement
#	name Basement Studios
#	homepage http://www.basement-studios.com/
#	type generate
#	imageurl http://www.basement-studios.com/archive/images/%m%d%y.gif
#	provides any
#end

strip btaf
	name Bob, The Angry Flower
	homepage http://angryflower.com/
	type search
	searchpattern <a.+?href="bobsqu.gif">.*?<a href="([^"]*\.gif)"
	provides latest
	baseurl http://angryflower.com/
end

strip boasas
	name Boy on a Stick and Slither
	homepage http://www.boasas.com/
	type search
	searchpattern <img.+?src="(boasas/\d+\..+?)"
	provides latest
	baseurl http://www.boasas.com/
end

strip brunothebandit
	name Bruno the Bandit
	homepage http://www.brunothebandit.com
	type generate
	imageurl http://www.brunothebandit.com/comics/%Y%m%da.gif
	provides any
end

strip dieselsweeties
	name Diesel Sweeties
	homepage http://www.dieselsweeties.com/
	type search
	searchpattern <img.+?src="(http://images.clango.org/strips/sw\d+\..+?)"
	provides latest
end

strip fuzzylogic
	name Fuzzy Logic
	homepage http://www.bbspot.com/comics/fuzzy_logic/index.html
	type generate
	imageurl http://www.bbspot.com/Images/comics/fuzzy_logic/%Y/%Y%m%d.jpg
	provides any
end

strip littlegamers
	name Little Gamers
	homepage http://www.little-gamers.com/
	type generate
	imageurl http://www.little-gamers.com/comics/%Y%m%d.gif
	provides any
end

# tuesdays, thursdays, sundays
strip machall
	name Mac Hall
	homepage http://www.MacHall.com/
	type search
	searchpattern <img.+?src='(/index.php\?do_command=show_strip\&strip_id=\d+\&auth=.+?)'
	baseurl $homepage
	provides latest
end

# not daily
strip mrchuckshow
	name Mr. Chuck Show
	homepage http://www.mrchuckshow.com/
	type generate
	imageurl http://www.mrchuckshow.com/strips/mcs%Y%m%db.png
	provides any
end

strip pentasmal
	name Pentasmal
	homepage http://www.pentasmal.com/
	type generate
	imageurl http://www.pentasmal.com/comics/%Y%m%d.png
	provides any
end

strip rpgworld
	name RPG World
	homepage http://www.rpgworldcomic.com/
	#type generate
	#imageurl http://www.rpgworldcomic.com/comics/%Y%m%d.jpg
	#provides any
	type search
	searchpattern <IMG.+?SRC="(/comics/.+?\..+?)"
	provides latest
	baseurl $homepage
end

# Ubersoft - multi-strip
strip ubersoft1
	name Ubersoft-1
	homepage http://www.ubersoft.net/
	type generate
	imageurl http://www.ubersoft.net/comics/hd%Y%m%da.png
	provides any
end

strip ubersoft2
	name Ubersoft-2
	homepage http://www.ubersoft.net/
	type generate
	imageurl http://www.ubersoft.net/comics/hd%Y%m%dc.png
	provides any
end

strip ubersoft3
	name Ubersoft-3
	homepage http://www.ubersoft.net/
	type generate
	imageurl http://www.ubersoft.net/comics/hd%Y%m%de.png
	provides any
end

strip ubersoft4
	name Ubersoft-4
	homepage http://www.ubersoft.net/
	type generate
	imageurl http://www.ubersoft.net/comics/hd%Y%m%dg.png
	provides any
end

strip spazlabs
	name Spaz Labs
	homepage http://www.stonebrokestudios.com
	type generate
	imageurl http://www.stonebrokestudios.com/archives/spaz/%y%m%dspaz.gif
	provides any
end

strip glasbergen
	name Randy Glasbergen
	homepage http://www.glasbergen.com
	type generate
	imageurl http://www.glasbergen.com/images/toon.gif
	provides latest
end

strip spiderman
	name Spider Man
	homepage http://www.kingfeatures.com/features/comics/spidermn/about.htm
	type search
	searchpage http://www.kingfeatures.com/features/comics/spidermn/aboutMaina.php
	searchpattern <img.+?src='(http://est.rbma.com/content/Spiderman\?date=\d{8})'
	provides latest
end

# can be made into a class
strip tuma
	name Kevin Tuma Cartoon
	homepage http://www.cnsnews.com/cartoon/Tuma.asp
	type search
	searchpage http://www.cnsnews.com/cartoon/tuma.asp
	searchpattern <img.+?border="0".+?src="(Tumaimages/%Y/\w+\..+?)"
	baseurl http://www.cnsnews.com/cartoon/
	provides latest
end

strip nowak
	name Paul Nowak Cartoon
	homepage http://www.cnsnews.com/cartoon/nowak.asp
	type search
	searchpattern <img.+?border="0".+?src="(Nowakimages/%Y/\w+\..+?)"
	baseurl http://www.cnsnews.com/cartoon/
	provides latest
end

strip asay
	name Chuck Asay Cartoon
	homepage http://www.cnsnews.com/cartoon/asay.asp
	type search
	searchpattern <img.+?border="0".+?src="(Asayimages/%Y/\w+\..+?)"
	baseurl http://www.cnsnews.com/cartoon/
	provides latest
end

strip lang
	name Bob Lang Cartoon
	homepage http://www.cnsnews.com/cartoon/lang.asp
	type search
	searchpage http://www.cnsnews.com/cartoon/Lang.asp
	searchpattern <img.+?border="0".+?src="(Langimages/%Y/\w+\..+?)"
	baseurl http://www.cnsnews.com/cartoon/
	provides latest
end

strip shelton
	name Barry Shelton Cartoon
	homepage http://www.cnsnews.com/cartoon/shelton.asp
	type search
	searchpattern <img.+?border="0".+?src="(Sheltonimages/%Y/.+?\..+?)"
	baseurl http://www.cnsnews.com/cartoon/
	provides latest
end

strip elflifeadult
	name Elf Life: R Rated
	homepage http://www.elflife.com/adults.html
	type generate
	imageurl http://www.elflife.com/current/%Y%m%dm.gif
	provides any
end

strip funnyfarm
	name Funny Farm
	homepage http://www.funnyfarmcomics.com/
	type search
	searchpage http://www.funnyfarmcomics.com/d/%Y%m%d.html
	searchpattern <IMG.+?SRC="(/comics/%Y%m%da\..+?)"
	baseurl $homepage
	provides any
end

strip elflife
	name Elf Life
	homepage http://www.elflife.com/
	type generate
	imageurl http://www.elflife.com/comics/%Y%m%dm.gif
	provides any
end

strip ozyandmillie
	name Ozy and Millie
	homepage http://www.ozyandmillie.org/
	type generate
	imageurl http://www.ozyandmillie.org/comics/om%Y%m%d.gif
	provides any
end

strip suburbanjungle
	name Suburban Jungle
	homepage http://www.suburbanjungle.com/
	type search
	searchpage http://suburbanjungle.com/d/%Y%m%d.html
	searchpattern <img.+?SRC="(/comics/sj%Y%m%d\..+?)"
	baseurl http://www.suburbanjungle.com
	provides any
end

strip acidreflux
	name Acid Reflux
	homepage http://www.acidrefluxcomic.com/
	type search
	baseurl http://www.acidrefluxcomic.com/
	searchpattern <img.+?src="(archive/c\d+\..+?)"
	provides latest
end

strip whenigrowup
	name When I Grow Up
	homepage http://www.whenigrowup.net/
	type generate
	imageurl http://www.whenigrowup.net/comics/wigu%Y%m%d.png
	provides any
end

strip walky
	name It's Walky
	homepage http://www.itswalky.com/
	baseurl $homepage
	type search
	searchpattern <IMG.+?ALT="".+?SRC="(.+?)".+?> <br>
	provides latest
end

strip jackiesfridge
	name Jackie's Fridge
	type generate
	homepage http://jackiesfridge.keenspace.com/
	imageurl http://jackiesfridge.keenspace.com/comics/jf%Y%m%da.jpg
	provides any
end

strip schlockmercenary
	name Schlock Mercenary
	type generate
	homepage http://www.schlockmercenary.com/
	imageurl http://www.schlockmercenary.com/comics/schlock%Y%m%d.png
	provides any
end

strip unicornjelly
	name Unicorn Jelly
	type search
	homepage http://unicornjelly.com/
	searchpattern <IMG.+?SRC="(images\/uni\d+\..+?)"
	baseurl $homepage
	provides latest
end

strip downtoearth
	name Down To Earth
	homepage http://downtoearth.ncbuy.com
	type generate
	imageurl http://downtoearth.ncbuy.com/img/syndicate/nav1_dte_today.gif
	provides latest
end

# website gone (?) 2002-05-24
#strip wandering
#	name Wandering Ones
#	homepage http://www.wanderingones.com/
#	type generate
#	imageurl http://www.wanderingones.com/comics/wan%Y%m%d.gif
#	provides any
#end

strip rvfun
	name Reverend Fun
	homepage http://rev-fun.gospelcom.net/
	type generate
	#imageurl http://rev-fun.gospelcom.net/%Y/%m/%Y%m%d.gif
	imageurl http://rev-fun.gospelcom.net/add_toon_info.php?date=%Y%m%d
	provides any
end

# no longer updated 2002-05-24
strip greytown
        name Living in Greytown
        homepage http://www.livingingreytown.com/
        type generate
        imageurl $homepage/comics/grey%Y%m%d.jpg
        provides any
end

strip slowwave
        name Slow Wave
        homepage http://www.slowwave.com/
        type generate
        imageurl $homepage/img.cgi?thisweek.gif
        provides latest
end

# formerly "The Thin H Line". NC-17. Vertical format.
strip sexylosers
	name Sexy Losers
	homepage http://sexylosers.keenspace.com/
	type search
	searchpattern <IMG.+?SRC.*?=.*?"(http://sexylosers\.(keenspace\.)?com/)?(images/sl\d+\.jpg)"
	#searchpattern <IMG.+?SRC="http://sexylosers=com/(images/sl\d+\.jpg)"
	matchpart 3
	provides latest
	baseurl $homepage
end

# weekly
strip youdamnkid
        name You Damn Kid
        homepage http://www.youdamnkid.com/
        type search
        baseurl $homepage
        provides latest
        searchpattern <IMG.+?SRC="/(comics/ydk\d+\.gif)"
end

# weekly, moving daily soon?
strip houndshome
        name Hound's Home
        homepage http://www.houndshome.com/
        type search
        baseurl $homepage
        provides latest
        searchpattern <IMG.+?SRC="/(comics/hh.+?)"
end

strip cutewendy
        name CuteWendy
        homepage http://www.wendycomic.com/
        type generate
        imageurl http://www.wendycomic.com/comics/wendy%Y%m%d.gif
        provides any
end

# sporadic
strip lifesorad
        name Life's So Rad
        homepage http://www.radcomics.com/
        type search
        baseurl $homepage
        provides latest
        searchpattern <IMG.+?SRC="/(comics/\d+.+?)"
end

# formerly known as otakufeh. NC-17.
strip bigones
        name Big Ones
        homepage http://otakufeh.keenspace.com/
        type generate
        provides any
        imageurl $homepage/comics/big%Y%m%d.gif
end

strip offthemark
	name Off the Mark
	homepage http://www.offthemark.com/
	type search
	provides latest
	searchpage $homepage/daily.asp
	searchpattern <img.+?src="(http://www.offthemark.com/rotate/\d+.gif)"
end

strip asif
	name As If
	homepage http://www.asifcomic.com/
	type search
	searchpattern img src="_left\.jpg" width=\d+ height=\d+ border=0"><img src="(.+?\.jpg)"
	baseurl $homepage
	provides latest
end

strip nipandtuck
	name Nip 'N Tuck
	homepage http://nipandtuck.keenspace.com
	type search
	searchpattern SRC="(/comics/nt(\d{8})\.gif)"
	baseurl $homepage
	provides latest
end

strip lemontree
	name Under The Lemon Tree
	homepage http://utlt.keenspace.com
	type search
	searchpattern SRC="(/comics/.+?(\d{8})\..+?)"
	baseurl $homepage
	provides latest
end

strip winter
	name Winter
	homepage http://www.wintercomic.com/
	type search
	#searchpattern img src='(pages/page(\d+)\.gif)'
	searchpattern <img.+?src='(/index.php\?do_command=show_strip&.+?)'
	baseurl $homepage
	provides latest
end

strip pcnpixel
	name PC and Pixel
	homepage http://www.pccomix.com/PCandPixel/
        type search
        searchpage http://www.pccomix.com/PCandPixel/pc_dailystrip/PCdaily.html
        searchpattern <p><img SRC="pc(\w+).gif".+?WIDTH=
        matchpart 1
        imageurl http://www.pccomix.com/PCandPixel/pc_dailystrip/pc$match.gif
        provides latest	
end

strip bobbins
	name Bobbins
	homepage http://www.bobbins.org/
	type search
	searchpage http://bobbins.org/d/%Y%m%d.html
	searchpattern <img.+?SRC="(/comics/%Y%m%d\..+?)"
	baseurl http://www.bobbins.org
	provides any
end

strip brainbuzz
	name Brainbuzz
	homepage http://cramsession.brainbuzz.com/lists/cartoon/
	type generate
	imageurl http://i.brainbuzz.com/CS/Lists/Cartoon/%y%m%d.gif
	#every day except saturday, sunday
	provides any
end

strip swamp
	name Swamp
	homepage http://www.swamp.com.au
	type search
	searchpage http://s1.emcs.com.au/SwampStrips/Strips/Strip.asp?Date=<code:strftime("%-d-%b-%Y", @localtime_today)>
	searchpattern <img.+?src="(http://s1.emcs.com.au/swampstrips/Strips_Images/\d+\..+?)"
	provides any
end

strip thenorm
	name The Norm
	homepage http://www.thenorm.com/
	type generate
	imageurl http://www.thenorm.com/arch/%y%m%d.gif
	provides any
end

strip somethingpositive
	name Something Positive
	homepage http://www.somethingpositive.net/
	type generate
	imageurl http://www.somethingpositive.net/arch/sp%m%d%Y.gif
	provides latest
end

strip melonpool
	name Melonpool
	homepage http://www.melonpool.com/
	type generate
	imageurl http://www.melonpool.com/comics/MM%Y%m%d.gif
	provides any
end

strip flem
        name FLEM!
        homepage http://www.flemcomics.com/
        type generate
        imageurl http://flem.dhs.org/new.jpg
        provides latest
end

# Updated Mon - Fri
strip reallife
        name Real Life
        homepage http://www.reallifecomics.com/
        type generate
        imageurl http://www.reallifecomics.com/comics/%Y%m%da.jpg
        provides any
end

# Updated Mon - Sat
strip sheldon
        name Sheldon
        useclass unitedmedia-srch-comics
end

# Updated Mon
strip weakendwarriors
        name Weak-end Warriors
        homepage http://www.inktank.com/WW/
        type generate
        imageurl http://www.inktank.com/images/WW/cartoons/%m-%d-%y.gif
        provides any
end

strip alice
	name Alice!
	homepage http://www.alicecomics.com/today.html
	type search
	searchpattern <IMG.+?SRC="(/comics/alice.+?\..+?)"
	baseurl http://www.alicecomics.com/
	provides latest
end

strip theshadows
	name The Shadows
	homepage http://www.alicecomics.com/shadows.html
	type search
	searchpattern <IMG.+?SRC="(/shadcomics/shad.+?\..+?)"
	baseurl http://www.alicecomics.com/
	provides latest
end

strip lcd
	name Lowest Common Denominator
	homepage http://lcd.keenspace.com
	type search
	searchpattern <IMG.+?SRC="(/comics/lcd.+?\..+?)"
	baseurl http://lcd.keenspace.com
	provides latest
end


strip devilspanties
	name The Devil's Panties
	homepage http://thedevilspanties.keenspace.com
	type search
	searchpattern <IMG.+?SRC="(/comics/.+?\..+?)"
	baseurl http://thedevilspanties.keenspace.com
	provides latest
end

strip fatjesus
	name Fat Jesus
	homepage http://www.fat-jesus.com
	type search
	searchpage http://fatjesus.keenspace.com
	searchpattern <IMG.+?SRC="(/comics/fatjesus.+?)"
	baseurl http://fatjesus.keenspace.com
	provides latest
end

strip funnyfarm
	name Funny Farm
	homepage http://www.funnyfarmcomics.com
	type search
	searchpattern <IMG.+?SRC="(/comics/.+?\..+?)"
	baseurl http://www.funnyfarmcomics.com
	provides latest
end

strip sexandviolence
	name Sex and Violence
	homepage http://www.mrbang.net
	type search
	searchpattern <IMG.+?SRC="(/comics/.+?\..+?)"
	baseurl http://www.mrbang.net
	provides latest
end

strip fans
	name Fans!
	homepage http://faans.com
	type search
	searchpattern <IMG.+?SRC="(http://faans.com/images/%Y/.+?\..+?)"
	provides latest
end

strip spooner
        name Spooner
        homepage http://www.hookedoncomics.com/
        type generate
        imageurl http://www.hookedoncomics.com/comics/Sp%Y%m%d.gif
        provides any
end

strip underpower
        name Under Power
        artist Jorge "Vaz" Rivas and David "vanishing" Trischuk
        homepage http://underpower.non-essential.com/
        type generate
        imageurl http://underpower.non-essential.com/comics/%Y%m%d.jpg
        provides any
end

strip nekobox
        name Nekobox
        artist Jorge "Vaz" Rivas and David "vanishing" Trischuk
        homepage http://www.nekobox.org
        type generate
        imageurl http://www.nekobox.org/comic/%Y-%m-%d.jpg
        provides any
end

strip perscheid
        name Perscheids Abgruende
        artist Martin Perscheid -> www.martin-perscheid.de
        homepage http://portale.web.de/Boulevard/Comics/Perscheid/
        type search
        searchpattern <img.+?src="(http://img.web.de/c/00.+?)"
        provides latest
end

strip harmbengen
        name Harm Bengen's Alltagsskizzen
        artist Harm Bergen -> www.harmbengen.de
        homepage http://portale.web.de/Boulevard/Comics/Bengen/
        type search
        searchpattern <img.+?src="(http://img.web.de/c/00.+?)"
        provides latest
end
strip weyershausenwelt
        name Weyershausen - Wunderbare Welt
        artist Karsten Weyershausen -> www.weyershausen.de
        homepage http://portale.web.de/Boulevard/Comics/Weyershausen/
        type search
        searchpattern <img.+?src="(http://img.web.de/c/00.+?)"
        provides latest
end

strip quirit
        name Quirit - alltaegliches auf den Punkt gebracht
        artist Quirit -> www.quirit.com
        homepage http://portale.web.de/Boulevard/Comics/Quirit/
        type search
        searchpattern <img.+?src="(http://img.web.de/c/00.+?)"
        provides latest
end

strip touche
        name Touche
        artist Tom
        homepage http://www.drive-in-cartoons.de/touche/
        type search
        searchpage http://www.drive-in-cartoons.de/touche/hauptteil.php
        searchpattern <img.+?src='(.+?)'
        baseurl http://www.drive-in-cartoons.de/touche/
        provides latest
end

# ucomics.com strips
strip adamathome
	name Adam@home
	useclass ucomics-gen
	$1 ad
end

strip baldo
	name Baldo
	useclass ucomics-gen
	$1 ba
end

strip bizarro
	name Bizarro
	useclass ucomics-gen
	$1 bz
end

strip thebigpicture
	name The Big Picture
	useclass ucomics-gen
	$1 bi
end

strip boondocks
	name The Boondocks
	useclass ucomics-gen
	$1 bo
end

strip calvinandhobbes
	name Calvin and Hobbes
	useclass ucomics-srch
	$1 ch
end

strip cathy
	name Cathy
	useclass ucomics-gen
	$1 ca
end

strip closetohome
	name Close to Home
	useclass ucomics-gen
	$1 cl
end

strip cornered
	name Cornered
	useclass ucomics-gen
	$1 co
end

# discontinued ar ucomics.com 2002-05-24
#strip crabbyroad
#	name Crabby Road
#	useclass ucomics-gen
#	$1 cr
#end

strip crankshaft
	name Crankshaft
	useclass ucomics-gen
	$1 cs
end

strip doonesbury
	name Doonesbury
	useclass ucomics-gen
	$1 db
end

strip thefifthwave
	name The 5th Wave
	useclass ucomics-srch
	$1 fw
end

strip foxtrot
	name FoxTrot
	useclass ucomics-gen
	$1 ft
end

strip thefuscobrothers
	name The Fusco Brothers
	useclass ucomics-gen
	$1 fu
end

strip garfield
	name Garfield
	useclass ucomics-gen
	$1 ga
end

strip heartofthecity
	name Heart of the City
	useclass ucomics-gen
	$1 hc
end

strip inthebleachers
	name In the Bleachers
	useclass ucomics-gen
	$1 bl
end

strip james
	name James
	useclass ucomics-gen
	$1 jm
end

strip misterboffo
	name Mister Boffo
	useclass ucomics-gen
	$1 mb
end

strip mrpotatohead
        name Mr. Potato Head
        useclass ucomics-gen
        $1 mrp
end

strip nonsequitur
	name Non Sequitur
	useclass ucomics-gen
	$1 nq
end

strip oddlyenough
	name Oddly Enough
	useclass ucomics-gen
	$1 oe
end

strip overboard
	name Overboard
	useclass ucomics-gen
	$1 ob
end

strip reallifeadventures
	name Real Life Adventures
	useclass ucomics-gen
	$1 rl
end

strip reynoldsunwrapped
	name Reynolds Unwrapped
	useclass ucomics-gen
	$1 rw
end

strip stonesoup
	name Stone Soup
	useclass ucomics-gen
	$1 ss
end

strip tankmcnamara
	name Tank McNamara
	useclass ucomics-gen
	$1 tm
end

strip tomthedancingbug
	name Tom the Dancing Bug
	useclass ucomics-srch
	$1 td
end

strip ziggy
	name Ziggy
	useclass ucomics-gen
	$1 zi
end

strip theduplex
        name The Duplex
        useclass ucomics-gen
        $1 dp
end

# unitedmedia.com strips
strip agnes
	name Agnes
	useclass unitedmedia-srch-creators
end

strip alleyoop
	name Alley Oop
	useclass unitedmedia-srch-comics
end

#strip andycapp
#	name Andy Capp
#	useclass unitedmedia-srch-creators
#end

strip arlonjanis
	name Arlo & Janis
	useclass unitedmedia-srch-comics
end

strip askshagg
	name Ask Shagg
	useclass unitedmedia-srch-creators
end

#strip bc
#	name B.C.
#	useclass unitedmedia-srch-creators
#end

strip ballardst
	name Ballard Street
	useclass unitedmedia-srch-creators
end

strip betty
	name Betty
	useclass unitedmedia-srch-comics
end

strip bignate
	name Big Nate
	useclass unitedmedia-srch-comics
end

strip bornloser
	name The Born Loser
	useclass unitedmedia-srch-comics
end

strip buckets
	name The Buckets
	useclass unitedmedia-srch-comics
end

strip bullsnbears
	name Bull$ 'N' Bear$
	useclass unitedmedia-srch-comics
end

strip cheapthrills
	name Cheap Thrills
	useclass unitedmedia-srch-wash
end

strip charlie
	name Charlie
	useclass unitedmedia-srch-creators
end

strip chickweed
	name 9 Chickweed Lane
	useclass unitedmedia-srch-comics
end

strip committed
	name Committed
	useclass unitedmedia-srch-comics
end

strip drabble
	name Drabble
	useclass unitedmedia-srch-comics
end

strip drawingacrowd
	name Drawing a Crowd
	useclass unitedmedia-srch-creators
end

strip dilbert
	name Dilbert
	useclass unitedmedia-srch-comics
end

strip fatcats
	name Fat Cats
	useclass unitedmedia-srch-comics-lag
end

strip ferdnand
	name Ferd'nand
	useclass unitedmedia-srch-comics
end

strip flightdeck
	name Flight Deck
	useclass unitedmedia-srch-creators
end

strip forbetter
	name For Better or For Worse
	useclass unitedmedia-srch-comics
end

strip forheavens
	name For Heaven's Sake
	useclass unitedmedia-srch-creators
end

strip franknernest
	name Frank & Ernest
	useclass unitedmedia-srch-comics
end

strip frazz
        name Frazz
        useclass unitedmedia-srch-comics
end

#can't use the class - dates are 66 years ago
strip freckles
	name Freckles and His Friends
	homepage http://www.unitedmedia.com/comics/freckles/index.html
	type search
	searchpattern <IMG.+?SRC="(/comics/freckles/archive/images/freckles.+?\..+?)"
	baseurl http://www.unitedmedia.com
	provides latest
end

strip geech
	name Geech
	useclass unitedmedia-srch-comics
end

strip getfuzzy
	name Get Fuzzy
	useclass unitedmedia-srch-comics
end

strip gingermeggs
	name Ginger Meggs
	useclass unitedmedia-srch-comics
end

strip graffiti
	name Graffiti
	useclass unitedmedia-srch-comics
end

strip grandave
	name Grand Avenue
	useclass unitedmedia-srch-comics
end

strip grizzwells
	name The Grizzwells
	useclass unitedmedia-srch-comics
end

strip heathcliff
	name Heathcliff
	useclass unitedmedia-srch-creators
end

strip hedge
	name Over the Hedge
	useclass unitedmedia-srch-comics
end

strip herbnjamaal
	name Herb and Jamaal
	useclass unitedmedia-srch-creators
end

strip herman
	name Herman
	useclass unitedmedia-srch-comics
end

strip janesworld
        name Jane's World
        useclass unitedmedia-srch-comics
end

strip jumpstart
	name Jump Start
	useclass unitedmedia-srch-comics
end

strip kitncarlyle
	name Kit 'N' Carlyle
	useclass unitedmedia-srch-comics
end

# appears to be gone - 2002-01-12
#strip liberty
#	name Liberty Meadows
#	useclass unitedmedia-srch-creators
#end

# disabled again 2002-04-02
#strip old_liberty
#	name Liberty Meadows
#	homepage http://www.sunnyfundays.com/
#	type search
#	searchpage http://www.sunnyfundays.com/comix.htm
#	searchpattern <img.+?SRC="(\d+.gif)".+?ALIGN="BOTTOM".+?BORDER="0".+?NATURALSIZEFLAG="3" 	
#	baseurl http://www.sunnyfundays.com/ 	provides latest
#end

#can't use the class - dates are 53 years ago
strip lilabner
	name Li'l Abner
	homepage http://www.unitedmedia.com/comics/lilabner/index.html
	type search
	searchpattern <img.+?src="(/comics/lilabner/archive/images/lilabner.+?\..+?)"
	baseurl http://www.unitedmedia.com
	provides latest
end

strip luann
	name Luann
	useclass unitedmedia-srch-comics
end

# last updated 22 oct 2001?
# seems gone: 2002-05-24
#strip lupo
#	name Lupo Alberto
#	useclass unitedmedia-srch-comics
#	searchpage $homepage
#	provides latest
#end

strip marmaduke
	name Marmaduke
	useclass unitedmedia-srch-comics
end

strip meatloaf
	name Meatloaf Night
	useclass unitedmedia-srch-comics
end

strip meg
	name Meg!
	useclass unitedmedia-srch-comics-lag
end

strip momma
	name Momma
	useclass unitedmedia-srch-creators
end

# lags ~1 week
strip motley
	name Motley
	useclass unitedmedia-srch-comics-lag
end

strip mspeach
	name Ms. Peach
	useclass unitedmedia-srch-creators
end

strip nancy
	name Nancy
	useclass unitedmedia-srch-comics
end

strip naturalselection
	name Natural Selection
	useclass unitedmedia-srch-creators
end

# gone from unitedmedia 2002-05-24
#strip offsides
#	name Offsides
#	useclass unitedmedia-srch-comics
#end

strip onebighappy
	name One Big Happy
	useclass unitedmedia-srch-creators
end

strip othercoast
	name The Other Coast
	useclass unitedmedia-srch-creators
end

strip peanuts
	name Peanuts
	useclass unitedmedia-srch-comics
end

strip pearls
	name Pearls Before Swine
	useclass unitedmedia-srch-comics
end

strip pibgorn
	name Pibgorn
	useclass unitedmedia-srch-comics
end

strip pickles
	name Pickles
	useclass unitedmedia-srch-wash
end

strip potluck
	name Potluck Parish
	useclass unitedmedia-srch-comics
end

strip raisingduncan
	name Raising Duncan
	useclass unitedmedia-srch-comics
end

strip randolphitch
	name Randolph Itch 2 a.m.
	useclass unitedmedia-srch-comics
end

strip reality
	name Reality Check
	useclass unitedmedia-srch-comics
end

strip redandrover
	name Red and Rover
	useclass unitedmedia-srch-wash
end

strip ripleys
	name Ripley's Believe It or Not!
	useclass unitedmedia-srch-comics
end

strip monty
	name Monty
	useclass unitedmedia-srch-comics
end

strip roseisrose
	name Rose Is Rose
	useclass unitedmedia-srch-comics
end

strip rubes
	name Rubes
	useclass unitedmedia-srch-creators
end

# discontinued at unitedmedia 2002-05-24
#strip rugrats
#	name Rugrats
#	useclass unitedmedia-srch-creators
#end

strip shirleynson
	name Shirley And Son
	useclass unitedmedia-srch-comics
end

strip soup2nutz
	name Soup To Nutz
	useclass unitedmedia-srch-comics
end

#gone? 2002-04-02
#strip spooner
#       name Spooner
#        useclass unitedmedia-srch-comics
#end

strip speedbump
	name Speed Bump
	useclass unitedmedia-srch-creators
end

# only once-weekly
strip stockcartoons
	name StockcarToons
	useclass unitedmedia-srch-comics
	#searchpage http://www.unitedmedia.com/comics/stockcartoons/archive/stockcartoons-<code:strftime("\%Y\%m\%d", localtime($time_today - 604800))>.html
	searchpage $homepage
	provides latest
end

strip strangebrew
	name Strange Brew
	useclass unitedmedia-srch-creators
end

strip tarzan
	name Tarzan
	useclass unitedmedia-srch-comics
end

#gone 10 feb 2002
#strip tmnt
#	name Teenage Mutant Ninja Turtles
#	useclass unitedmedia-srch-creators
#end

strip thatslife
	name That's Life
	useclass unitedmedia-srch-wash
end

strip topofworld
	name Top of the World!
	useclass unitedmedia-srch-comics-lag
end

strip usplay
	name The US of Play
	useclass unitedmedia-srch-comics
end

strip warped
	name Warped
	useclass unitedmedia-srch-comics
end

# gone? 2002-04-02
#strip weepals
#	name Wee Pals
#	useclass unitedmedia-srch-creators
#end

#strip wizardofid
#	name Wizard of Id
#	useclass unitedmedia-srch-creators
#end

strip workingdaze
	name Working Daze
	useclass unitedmedia-srch-comics
end

strip billday
	name Bill Day
	useclass unitedmedia-srch-editoons
	$1 day
end

strip billschorr
	name Bill Schorr
	useclass unitedmedia-srch-editoons
	$1 schorr
end

strip claybennett
	name Clay Bennett
	useclass unitedmedia-srch-editoons
	$1 bennett
end

strip drewlitton
	name Drew Litton
	useclass unitedmedia-srch-editoons
	$1 litton
end

strip edstein
	name Ed Stein
	useclass unitedmedia-srch-editoons
	$1 stein
end

strip ettahulme
	name Etta Hulme
	useclass unitedmedia-srch-editoons
	$1 hulme
end

strip henrypayne
	name Henry Payne
	useclass unitedmedia-srch-editoons
	$1 payne
end

strip jeffstahler
	name Jeff Stahler
	useclass unitedmedia-srch-editoons
	$1 stahler
end

strip jerryholbert
	name Jerry Holbert
	useclass unitedmedia-srch-editoons
	$1 holbert
end

strip jimberry
	name Jim Berry
	useclass unitedmedia-srch-editoons
	$1 berry
end

strip mikesmith
	name Mike Smith
	useclass unitedmedia-srch-editoons
	$1 smith
end

strip robrogers
	name Rob Rogers
	useclass unitedmedia-srch-editoons
	$1 rogers
end

strip robertariail
	name Robert Ariail
	useclass unitedmedia-srch-editoons
	$1 ariail
end

strip stevebenson
	name Steve Benson
	useclass unitedmedia-srch-editoons
	$1 benson
end

# sfgate strips
strip babyblues
	name Baby Blues
	useclass sfgate-gen
	$1 Baby_Blues
end

strip beetlebailey
	name Beetle Bailey
	useclass sfgate-gen
	$1 Beetle_Bailey
end

strip blondie
	name Blondie
	useclass sfgate-gen
	$1 $name
end

strip crock
	name Crock
	useclass sfgate-gen
	$1 $name
end

strip curtis
	name Curtis
	useclass sfgate-gen
	$1 $name
end

strip dennisthemenace
	name Dennis the Menace
	useclass sfgate-gen
	$1 Dennis_The_Menace
end

strip farley
	name Farley
	useclass sfgate-srch
	$1 $name
	$2 farley
end

strip fastrack
	name On The Fast Track
	useclass sfgate-gen
	$1 Fast_Track
end

strip funkywinkerbean
	name Funky Winkerbean
	useclass sfgate-gen
	$1 Funky_Winkerbean
end

strip hagarthehorrible
	name Hagar the Horrible
	useclass sfgate-gen
	$1 Hagar_The_Horrible
end

strip ineedhelp
	name I Need Help
	useclass sfgate-gen
	$1 Hagar_The_Horrible
end

strip mallardfillmore
	name Mallard Fillmore
	useclass sfgate-gen
	$1 Mallard_Fillmore
end

strip mutts
	name Mutts
	useclass sfgate-gen
	$1 $name
end

strip newbreed
	name New Breed
	useclass sfgate-gen
	$1 New_Breed
end

strip thephantom
	name The Phantom
	useclass sfgate-gen
	$1 Phantom
end

strip piranhaclub
	name Piranha Club
	useclass sfgate-gen
	$1 Piranha
end

strip popeye
	name Popeye
	useclass sfgate-gen
	$1 $name
end

strip rhymeswithorange
	name Rhymes with Orange
	useclass sfgate-gen
	$1 Rhymes_with_Orange
end

strip sallyforth
	name Sally Forth
	useclass sfgate-gen
	$1 Sally_Forth
end

strip safehavn
	name Safe Havens
	useclass sfgate-gen
	$1 Safe_Havens
end

strip shermanslagoon
	name Sherman's Lagoon
	useclass sfgate-gen
	$1 Shermans_Lagoon
end

strip sixchix
	name Six Chix
	useclass sfgate-gen
	$1 6Chix
end

strip willynethel
	name Willy 'n' Ethel
	useclass sfgate-gen
	$1 Willy_n_Ethel
end

strip zippythecolorpinhead
	name Zippy the Pinhead (in color)
	useclass sfgate-gen-zippycolor
	$1 Zippy_the_Color_Pinhead
	$2 Zippy_the_Pinhead
end

strip zippythepinhead
	name Zippy the Pinhead
	useclass sfgate-gen
	$1 Zippy_the_Pinhead
	$2 zippy
end

strip zits
	name Zits
	useclass sfgate-gen
	$1 $name
end

#comicspage.com strips
strip animal
	name Animal Crackers
	useclass comicspage-strips-gen
	$1 animal
	$2 ack
end

strip annie
	name Annie
	useclass comicspage-strips-gen
	$1 annie
	$2 ann
end

strip bound
	name Bound and Gagged
	useclass comicspage-strips-gen
	$1 bound
	$2 bgg
end

strip brenda
	name Brenda Starr
	useclass comicspage-strips-gen
	$1 brenda
	$2 bsr
end

strip broomhilda
	name Broom Hilda
	useclass comicspage-strips-gen
	$1 broomhilda
	$2 bhl
end

strip cats
	name Cats with Hands
	useclass comicspage-strips-gen
	$1 cats
	$2 cwh
end

# gone? 2002-04-02
#strip deardudley
#	name Dear Dudley
#	useclass comicspage-strips-gen
#	$1 deardudley
#	$2 drd
#end

strip dicktracy
	name Dick Tracy
	useclass comicspage-strips-gen
	$1 dicktracy
	$2 dty
end

strip fred
	name Fred Basset
	useclass comicspage-strips-gen
	$1 fred
	$2 fbt
end

strip gasolinealley
	name Gasoline Alley
	useclass comicspage-strips-gen
	$1 gasolinealley
	$2 gas
end

strip gilthorp
	name Gil Thorp
	useclass comicspage-strips-gen
	$1 gilthorp
	$2 gtp
end

strip grimmy
	name Mother Goose and Grimm
	useclass comicspage-strips-gen
	$1 grimmy
	$2 mgg
end

strip helen
	name Helen, Sweetheart of the Internet
	useclass comicspage-strips-gen
	$1 helen
	$2 hln
end

strip kudzu
	name Kudzu
	useclass comicspage-strips-gen
	$1 kudzu
	$2 kdz
end

strip lola
	name Lola
	useclass comicspage-strips-gen
	$1 lola
	$2 lol
end

strip lewis
	name Lewis
	useclass comicspage-strips-gen
	$1 lewis
	$2 lew
end

strip meehan
	name Meehan Streak
	useclass comicspage-strips-gen
	$1 meehan
	$2 mst
end

strip middletons
	name The Middletons
	useclass comicspage-strips-gen
	$1 middletons
	$2 mid
end

strip mixedmedia
	name Mixed Media
	useclass comicspage-strips-gen
	$1 mixedmedia
	$2 mix
end

strip monkeyhouse
	name Monkeyhouse
	useclass comicspage-strips-gen
	$1 monkeyhouse
	$2 mhs
end

strip shoe
	name Shoe
	useclass comicspage-strips-gen
	$1 shoe
	$2 sho
end

strip sylvia
	name Sylvia
	useclass comicspage-strips-gen
	$1 sylvia
	$2 syl
end

strip 9to5
	name 9 to 5
	useclass comicspage-panels-gen
	$1 9to5
	$2 ntf
end

strip bottomliners
	name Bottom Liners
	useclass comicspage-panels-gen
	$1 bottomliners
	$2 bls
end

strip computoon
	name Compu-toon
	useclass comicspage-panels-gen
	$1 computoon
	$2 cpt
end

strip looseparts
	name Loose Parts
	useclass comicspage-panels-gen
	$1 looseparts
	$2 lsp
end

strip loveis
	name Love Is...
	useclass comicspage-panels-gen
	$1 loveis
	$2 lis
end

strip pluggers
	name Pluggers
	useclass comicspage-panels-gen
	$1 pluggers
	$2 plg
end

strip quigmans
	name The Quiqmans
	useclass comicspage-panels-gen
	$1 quigmans
	$2 qgm
end

#strip singleslices
#	name Single Slices
#	useclass comicspage-panels-gen
#	$1 singleslices
#	$2 slc
#end

# gone? 2002-05-24
strip thatsjake
	name That's Jake
	useclass comicspage-panels-gen
	$1 thatsjake
	$2 tjk
end

strip conrad
	name Paul Conrad
	useclass comicspage-editorial-gen
	$1 conrad
	$2 con
end

# now at www.danzigercartoons.com
strip danziger
	name Jeff Danziger
	useclass comicspage-editorial-gen
	$1 danziger
	$2 dan
end

strip davies
	name Matt Davies
	useclass comicspage-editorial-gen
	$1 davies
	$2 dav
end

strip handelsman
	name Walt Handelsman
	useclass comicspage-editorial-gen
	$1 handelsman
	$2 han
end

strip horsey
	name David Horsey
	useclass comicspage-editorial-gen
	$1 horsey
	$2 hor
end

strip jones
	name Taylor Jones
	useclass comicspage-editorial-gen
	$1 jones
	$2 jon
end

strip locher
	name Dick Locher
	useclass comicspage-editorial-gen
	$1 locher
	$2 dik
end

strip lowe
	name Chan Lowe
	useclass comicspage-editorial-gen
	$1 lowe
	$2 low
end

strip marlette
	name Doug Marlette
	useclass comicspage-editorial-gen
	$1 marlette
	$2 mar
end

# gone? 2002-04-02
#strip ohman
#	name Jack Ohman
#	useclass comicspage-editorial-gen
#	$1 ohman
#	$2 ohm
#end

strip peters
	name Mike Peters
	useclass comicspage-editorial-gen
	$1 peters
	$2 pet
end

strip sack
	name Steve Sack
	useclass comicspage-editorial-gen
	$1 sack
	$2 sak
end

strip sheneman
	name Drew Sheneman
	useclass comicspage-editorial-gen
	$1 sheneman
	$2 she
end


strip stayskal
	name Wayne Stayskal
	useclass comicspage-editorial-gen
	$1 stayskal
	$2 sty
end

# gone? 2002-04-02
#strip summers
#	name Dana Summers
#	useclass comicspage-editorial-gen
#	$1 summers
#	$2 sum
#end

strip telnaes
	name Ann Telnaes
	useclass comicspage-editorial-gen
	$1 telnaes
	$2 tel
end

strip wasserman
	name Dan Wasserman
	useclass comicspage-editorial-gen
	$1 wasserman
	$2 was
end

strip wrightd
	name Dick Wright
	useclass comicspage-editorial-gen
	$1 wrightd
	$2 dwr
end

strip wright
	name Don Wright
	useclass comicspage-editorial-gen
	$1 wright
	$2 wrt
end

strip captainribman
	name Captain RibMan
	homepage http://www.comicspage.com/ribman/index.html
	type search
	searchpage http://www.supercomics.com/strips/new.html
	searchpattern <img.+?src="(.+?)".+?ALT="Captain RibMan"
	baseurl http://www.supercomics.com/strips/
	provides latest
end

#mercury center strips
strip bfriends
	name Between Friends
	useclass mercurycenter
	$1 14
	$2 bfriends
end


# sev.com.au strips
strip sevtrek
        name Sev Trek
        useclass sev-comics
end

strip fotr
        name Fraud of the Rings
        useclass sev-comics
end

strip sevgate
        name Sevgate SEV1
        useclass sev-comics
end

strip bluffy
        name Bluffy the Vampedup Stunner
        useclass sev-comics
end

strip sevfiles
        name The Sev Files
        useclass sev-comics
end

strip sevwars
        name Sev Wars
        useclass sev-comics
end

strip sevylon5
        name Sevylon 5
        useclass sev-comics
end

# doesn't fit class
strip sevscifi
        name Sev Sci-Fi TV
        homepage http://www.sev.com.au/toonzone/
        type generate
        imageurl http://www.sev.com.au/toonzone/scifitv.jpg
        provides latest
end

#washpost strips
strip andycapp
        name Andy Capp
        useclass washpost-creators
        $1 cap
end

strip wizardofid
        name Wizard of Id
        useclass washpost-creators
        $1 wiz
end

strip bc
        name BC
        useclass washpost-creators
        $1 bc
end

strip marvin
        name Marvin
        useclass washpost-king
        $1 $name
end